"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileSystemTransformer = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
class FileSystemTransformer {
    constructor({ allowedExtensions, sourcePath, }) {
        this.allowedExtensions = allowedExtensions;
        this.sourcePath = sourcePath;
    }
    run() {
        if (!fs_1.existsSync(this.sourcePath)) {
            throw new Error(`The path '${this.sourcePath}' is not exists.`);
        }
        const stats = fs_1.statSync(this.sourcePath);
        if (!stats.isDirectory()) {
            throw new Error(`The path '${this.sourcePath}' must be directory`);
        }
        return this.readFromDirectory(this.sourcePath);
    }
    readFromDirectory(path, prefix = '') {
        return fs_1.readdirSync(path).reduce((fileNamesObj, fileName) => {
            const fileFullPath = `${path}/${fileName}`;
            const stats = fs_1.statSync(fileFullPath);
            const ext = path_1.extname(fileFullPath);
            if (stats.isDirectory()) {
                return Object.assign(Object.assign({}, fileNamesObj), this.readFromDirectory(fileFullPath, `${fileName}/`));
            }
            if (!this.allowedExtensions.includes(ext)) {
                return Object.assign({}, fileNamesObj);
            }
            const baseName = path_1.basename(fileName).split('.').slice(0, -1).join('.');
            return Object.assign(Object.assign({}, fileNamesObj), { [`${prefix}${baseName}`]: fs_1.readFileSync(`${path}/${fileName}`).toString('utf-8') });
        }, {});
    }
}
exports.FileSystemTransformer = FileSystemTransformer;
