"use strict";
const command_1 = require("@oclif/command");
const file_system_transformer_1 = require("./core/file-system-transformer");
const manager_1 = require("./core/manager");
const svg_parser_1 = require("./core/svg-parser");
const json_output_handler_1 = require("./core/json-output-handler");
const fs_1 = require("fs");
const lodash_1 = require("lodash");
const path_1 = require("path");
class SvgToJson extends command_1.Command {
    constructor() {
        super(...arguments);
        this.defaults = {
            source: '',
            destination: process.cwd(),
            allowedExtensions: ['.svg'],
        };
    }
    async run() {
        const { flags } = this.parse(SvgToJson);
        const resolvedConfig = Object.assign(Object.assign(Object.assign({}, this.defaults), this.resolveConfig(await this.readConfig(flags.config))), this.resolveConfig(flags));
        if (!resolvedConfig.source) {
            this.error('Must have source.');
        }
        const manager = new manager_1.Manager({
            transformer: new file_system_transformer_1.FileSystemTransformer({
                allowedExtensions: resolvedConfig.allowedExtensions,
                sourcePath: resolvedConfig.source,
            }),
            parser: new svg_parser_1.SvgParser(),
            outputHandler: new json_output_handler_1.JsonOutputHandler({
                destinationPath: resolvedConfig.destination,
            }),
        });
        return manager.transform().parse().output();
    }
    async readConfig(configPath) {
        if (configPath && !fs_1.existsSync(configPath)) {
            this.error(`'${configPath}' is not exists.`);
        }
        configPath = configPath ? configPath : `${process.cwd()}/icons.config.js`;
        if (!fs_1.existsSync(configPath)) {
            return {};
        }
        const result = await Promise.resolve().then(() => require(configPath));
        if (!(result instanceof Object)) {
            return {};
        }
        return result;
    }
    resolveConfig(data) {
        return lodash_1.mapValues(lodash_1.pick(data, ['source', 'destination', 'allowedExtensions']), (value, key) => {
            if (key === 'allowedExtensions' && typeof value === 'string') {
                return lodash_1.split(value, ',');
            }
            if (['source', 'destination'].includes(key)) {
                return path_1.resolve(value);
            }
            return value;
        });
    }
}
SvgToJson.description = 'describe the command here';
SvgToJson.flags = {
    version: command_1.flags.version({ char: 'v' }),
    help: command_1.flags.help({ char: 'h' }),
    force: command_1.flags.boolean({ char: 'f' }),
    source: command_1.flags.string({
        char: 's',
        description: 'source path to svg icons directory.',
    }),
    allowedExtensions: command_1.flags.string({
        char: 'a',
        description: 'allowed extensions.',
    }),
    destination: command_1.flags.string({
        char: 'd',
        description: 'output destination path.',
    }),
    config: command_1.flags.string({
        char: 'c',
        description: 'config file.',
        default: '',
    }),
};
SvgToJson.args = [];
module.exports = SvgToJson;
